Tkinter, step 5: remove lib-tk subdirectory and update all places where it was mentioned.
diff --git a/Makefile.pre.in b/Makefile.pre.in
index 3b96df7..976e54f 100644
--- a/Makefile.pre.in
+++ b/Makefile.pre.in
@@ -808,7 +808,7 @@
 	plat-mac/lib-scriptpackages/SystemEvents \
 	plat-mac/lib-scriptpackages/Terminal 
 PLATMACPATH=:plat-mac:plat-mac/lib-scriptpackages
-LIBSUBDIRS=	lib-tk site-packages test test/output test/data \
+LIBSUBDIRS=	tkinter site-packages test test/output test/data \
 		test/decimaltestdata \
 		encodings \
 		email email/mime email/test email/test/data \
diff --git a/Misc/RPM/python-3.0.spec b/Misc/RPM/python-3.0.spec
index bf88739..f61a83c 100644
--- a/Misc/RPM/python-3.0.spec
+++ b/Misc/RPM/python-3.0.spec
@@ -376,7 +376,7 @@
 %if %{include_tkinter}
 %files tkinter
 %defattr(-,root,root)
-%{__prefix}/%{libdirname}/python%{libvers}/lib-tk
+%{__prefix}/%{libdirname}/python%{libvers}/tkinter
 %{__prefix}/%{libdirname}/python%{libvers}/lib-dynload/_tkinter.so*
 %endif
 
diff --git a/Modules/Setup.dist b/Modules/Setup.dist
index 1c07158..6c201c9 100644
--- a/Modules/Setup.dist
+++ b/Modules/Setup.dist
@@ -94,11 +94,7 @@
 MACHDEPPATH=:plat-$(MACHDEP)
 EXTRAMACHDEPPATH=
 
-# Path component for the Tkinter-related modules
-# The TKPATH variable is always enabled, to save you the effort.
-TKPATH=:lib-tk
-
-COREPYTHONPATH=$(DESTPATH)$(SITEPATH)$(TESTPATH)$(MACHDEPPATH)$(EXTRAMACHDEPPATH)$(TKPATH)
+COREPYTHONPATH=$(DESTPATH)$(SITEPATH)$(TESTPATH)$(MACHDEPPATH)$(EXTRAMACHDEPPATH)
 PYTHONPATH=$(COREPYTHONPATH)
 
 
diff --git a/PC/VS7.1/python.iss b/PC/VS7.1/python.iss
index 40365be..70c9bf3 100644
--- a/PC/VS7.1/python.iss
+++ b/PC/VS7.1/python.iss
@@ -180,6 +180,7 @@
 Source: Lib\xml\*.*; DestDir: {app}\Lib\xml; CopyMode: alwaysoverwrite; Components: main; Flags: recursesubdirs
 Source: Lib\hotshot\*.*; DestDir: {app}\Lib\hotshot; CopyMode: alwaysoverwrite; Components: main; Flags: recursesubdirs
 Source: Lib\test\*.*; DestDir: {app}\Lib\test; CopyMode: alwaysoverwrite; Components: test; Flags: recursesubdirs
+Source: Lib\tkinter\*.py; DestDir: {app}\Lib\tkinter; CopyMode: alwaysoverwrite; Components: tk; Flags: recursesubdirs
 
 Source: Lib\site-packages\README.txt; DestDir: {app}\Lib\site-packages; CopyMode: alwaysoverwrite; Components: main
 
@@ -188,8 +189,6 @@
 Source: Lib\site-packages\win32com\*.*; DestDir: {app}\Lib\site-packages\win32com; CopyMode: alwaysoverwrite; Components: main; Flags: recursesubdirs
 Source: Lib\site-packages\win32comext\*.*; DestDir: {app}\Lib\site-packages\win32comext; CopyMode: alwaysoverwrite; Components: main; Flags: recursesubdirs
 
-Source: Lib\lib-tk\*.py; DestDir: {app}\Lib\lib-tk; CopyMode: alwaysoverwrite; Components: tk; Flags: recursesubdirs
-
 Source: include\*.h; DestDir: {app}\include; CopyMode: alwaysoverwrite; Components: main
 
 Source: Tools\idle\*.*; DestDir: {app}\Tools\idle; CopyMode: alwaysoverwrite; Components: tk; Flags: recursesubdirs
@@ -239,7 +238,6 @@
 Root: HKLM; Subkey: SOFTWARE\Python\PythonCore; Flags: uninsdeletekeyifempty
 Root: HKLM; Subkey: SOFTWARE\Python\PythonCore\2.2; Flags: uninsdeletekeyifempty
 Root: HKLM; Subkey: SOFTWARE\Python\PythonCore\2.2\PythonPath; ValueData: "{app}\Lib;{app}\DLLs"; Flags: uninsdeletekeyifempty
-Root: HKLM; Subkey: SOFTWARE\Python\PythonCore\2.2\PythonPath\tk; ValueData: {app}\Lib\lib-tk; Flags: uninsdeletekey; Components: tk
 Root: HKLM; Subkey: SOFTWARE\Python\PythonCore\2.2\PythonPath\win32; ValueData: "{app}\lib\site-packages\win32;{app}\lib\site-packages\win32\lib"; Flags: uninsdeletekey
 Root: HKLM; Subkey: SOFTWARE\Python\PythonCore\2.2\PythonPath\win32com; ValueData: C:\Python\lib\site-packages; Flags: uninsdeletekey
 Root: HKLM; Subkey: SOFTWARE\Python\PythonCore\2.2\Modules; Flags: uninsdeletekeyifempty
@@ -294,9 +292,9 @@
 Name: {app}\Lib\lib-old\*.pyc; Type: files
 Name: {app}\Lib\lib-old\*.pyo; Type: files
 Name: {app}\Lib\lib-old; Type: dirifempty
-Name: {app}\Lib\lib-tk\*.pyc; Type: files
-Name: {app}\Lib\lib-tk\*.pyo; Type: files
-Name: {app}\Lib\lib-tk; Type: dirifempty
+Name: {app}\Lib\tkinter\*.pyc; Type: files
+Name: {app}\Lib\tkinter\*.pyo; Type: files
+Name: {app}\Lib\tkinter; Type: dirifempty
 Name: {app}\Lib\test\*.pyc; Type: files
 Name: {app}\Lib\test\*.pyo; Type: files
 Name: {app}\Lib\test; Type: dirifempty
diff --git a/PC/VS7.1/python20.wse b/PC/VS7.1/python20.wse
index fa11af4..6c1c387 100644
--- a/PC/VS7.1/python20.wse
+++ b/PC/VS7.1/python20.wse
@@ -2040,8 +2040,8 @@
 item: Remark
 end
 item: Install File
-  Source=..\lib\lib-tk\*.py
-  Destination=%MAINDIR%\Lib\lib-tk
+  Source=..\lib\tkinter\*.py
+  Destination=%MAINDIR%\Lib\tkinter
   Description=Tkinter related library modules
   Flags=0000000000000010
 end
@@ -2726,7 +2726,7 @@
 item: Edit Registry
   Total Keys=1
   Key=Software\Python\PythonCore\%PY_VERSION%\PythonPath
-  New Value=%MAINDIR%\Lib;%MAINDIR%\DLLs;%MAINDIR%\Lib\lib-tk
+  New Value=%MAINDIR%\Lib;%MAINDIR%\DLLs
   New Value=
   Root=2
 end
@@ -2764,7 +2764,7 @@
 item: Edit Registry
   Total Keys=1
   Key=Software\Python\PythonCore\%PY_VERSION%\PythonPath
-  New Value=%MAINDIR%\Lib;%MAINDIR%\DLLs;%MAINDIR%\Lib\lib-tk
+  New Value=%MAINDIR%\Lib;%MAINDIR%\DLLs
   New Value=
   Root=1
 end
diff --git a/PC/getpathp.c b/PC/getpathp.c
index 3a250be..e2beec1 100644
--- a/PC/getpathp.c
+++ b/PC/getpathp.c
@@ -25,7 +25,7 @@
      is set, we believe it.  Otherwise, we use the path of our host .EXE's
      to try and locate our "landmark" (lib\\os.py) and deduce our home.
      - If we DO have a Python Home: The relevant sub-directories (Lib, 
-       plat-win, lib-tk, etc) are based on the Python Home
+       plat-win, etc) are based on the Python Home
      - If we DO NOT have a Python Home, the core Python Path is
        loaded from the registry.  This is the main PythonPath key, 
        and both HKLM and HKCU are combined to form the path)
diff --git a/PC/os2emx/getpathp.c b/PC/os2emx/getpathp.c
index 5839eab..9e37f63 100644
--- a/PC/os2emx/getpathp.c
+++ b/PC/os2emx/getpathp.c
@@ -17,7 +17,7 @@
      is set, we believe it.  Otherwise, we use the path of our host .EXE's
      to try and locate our "landmark" (lib\\os.py) and deduce our home.
      - If we DO have a Python Home: The relevant sub-directories (Lib, 
-       plat-win, lib-tk, etc) are based on the Python Home
+       plat-win, etc) are based on the Python Home
      - If we DO NOT have a Python Home, the core Python Path is
        loaded from the registry.  This is the main PythonPath key, 
        and both HKLM and HKCU are combined to form the path)
diff --git a/PC/os2vacpp/pyconfig.h b/PC/os2vacpp/pyconfig.h
index f7d388c..2765b44 100644
--- a/PC/os2vacpp/pyconfig.h
+++ b/PC/os2vacpp/pyconfig.h
@@ -66,7 +66,7 @@
 #define PYCC_VACPP  /* Define Indicator of C Compiler */
 
   /* Platform Filesystem */
-#define PYTHONPATH  ".;.\\lib;.\\lib\\plat-win;.\\lib\\lib-tk"
+#define PYTHONPATH  ".;.\\lib;.\\lib\\plat-win"
 #define DOSFILESYS  /* OS/2 Uses the DOS File Naming Conventions */
 /* #define IMPORT_8x3_NAMES (let's move up to long filenames) */
 
diff --git a/PC/pyconfig.h b/PC/pyconfig.h
index e38e823..b64561b 100644
--- a/PC/pyconfig.h
+++ b/PC/pyconfig.h
@@ -80,7 +80,7 @@
 #define MS_WIN32 /* only support win32 and greater. */
 #define MS_WINDOWS
 #ifndef PYTHONPATH
-#	define PYTHONPATH L".\\DLLs;.\\lib;.\\lib\\plat-win;.\\lib\\lib-tk"
+#	define PYTHONPATH L".\\DLLs;.\\lib;.\\lib\\plat-win"
 #endif
 #define NT_THREADS
 #define WITH_THREAD
diff --git a/Tools/msi/msi.py b/Tools/msi/msi.py
index a57224a..f951256 100644
--- a/Tools/msi/msi.py
+++ b/Tools/msi/msi.py
@@ -910,14 +910,14 @@
         print("WARNING: _ctypes.pyd not found, ctypes will not be included")
         extensions.remove("_ctypes.pyd")
 
     # Add all .py files in Lib, except lib-tk, test
     dirs={}
     pydirs = [(root,"Lib")]
     while pydirs:
         parent, dir = pydirs.pop()
         if dir == ".svn" or dir.startswith("plat-"):
             continue
-        elif dir in ["lib-tk", "idlelib", "Icons"]:
+        elif dir in ["tkinter", "idlelib", "Icons"]:
             if not have_tcl:
                 continue
             tcltk.set_current()
@@ -1186,7 +1186,7 @@
               ("InstallGroup", -1, prefix+r"\InstallPath\InstallGroup", "",
                "Python %s" % short_version, "REGISTRY"),
               ("PythonPath", -1, prefix+r"\PythonPath", "",
-               r"[TARGETDIR]Lib;[TARGETDIR]DLLs;[TARGETDIR]Lib\lib-tk", "REGISTRY"),
+               r"[TARGETDIR]Lib;[TARGETDIR]DLLs", "REGISTRY"),
               ("Documentation", -1, prefix+r"\Help\Main Python Documentation", "",
                "[TARGETDIR]Doc\\"+docfile , "REGISTRY.doc"),
               ("Modules", -1, prefix+r"\Modules", "+", None, "REGISTRY"),
@@ -910,14 +910,14 @@
         extensions.remove("_ctypes.pyd")
 
-    # Add all .py files in Lib, except lib-tk, test
+    # Add all .py files in Lib, except tkinter, test
     dirs={}
     pydirs = [(root,"Lib")]